@@ -8,6 +8,7 @@ from .Graph import Graph
 from .Input import Input
 from .Interval import Interval
 from .Link import Link
+from .Loading import Loading
 from .Location import Location
 from .LogoutButton import LogoutButton
 from .Markdown import Markdown
@@ -15,7 +16,6 @@ from .RadioItems import RadioItems
 from .RangeSlider import RangeSlider
 from .Slider import Slider
 from .Store import Store
-from .SyntaxHighlighter import SyntaxHighlighter
 from .Tab import Tab
 from .Tabs import Tabs
 from .Textarea import Textarea
@@ -32,6 +32,7 @@ __all__ = [
     "Input",
     "Interval",
     "Link",
+    "Loading",
     "Location",
     "LogoutButton",
     "Markdown",
@@ -39,7 +40,6 @@ __all__ = [
     "RangeSlider",
     "Slider",
     "Store",
-    "SyntaxHighlighter",
     "Tab",
     "Tabs",
     "Textarea",
